@@ -17,12 +17,19 @@ import logging
 
 from subiquitycore.core import Application
 
+from console_conf.models.console_conf import ConsoleConfModel
+
 log = logging.getLogger('console_conf.core')
 
 
 class ConsoleConf(Application):
 
+    from console_conf.palette import COLORS, STYLES, STYLES_MONO
+
     project = "console_conf"
+
+    make_model = ConsoleConfModel
+
     controllers = [
         "Welcome",
         "Network",
